pub enum CommandError {
ZeroPrice,
ZeroQuantity,
IcebergZeroHiddenQuantity,
IcebergZeroReplenishQuantity,
IcebergImmediateTif,
PostOnlyImmediateTif,
PeggedNonTakerImmediateTif,
PeggedAlwaysTakerPostOnly,
EmptyPatch,
Expired,
SameLevelImmediateTif,
}Expand description
Error that violates the invariants of a command
Variants
ZeroPrice
The price of the order is zero
ZeroQuantity
The quantity of the order is zero
IcebergZeroHiddenQuantity
The hidden quantity of the iceberg order is zero
IcebergZeroReplenishQuantity
The replenish quantity of the iceberg order is zero
IcebergImmediateTif
The iceberg order has an immediate time in force
PostOnlyImmediateTif
The order is post-only but has an immediate time in force
PeggedNonTakerImmediateTif
The pegged order cannot be a taker but has an immediate time in force
PeggedAlwaysTakerPostOnly
The pegged order is always a taker but is post-only
EmptyPatch
The patch is empty
Expired
The command has expired
SameLevelImmediateTif
The order stays at the same level but becomes having an immediate time in force