TimeInForce

Enum TimeInForce 

pub enum TimeInForce {
    Gtc,
    Ioc,
    Fok,
    Gtd(Timestamp),
}
Specifies how long an order remains active before it is executed or expires.

Variants



Gtc

Good ’Til Canceled - The order remains active until it is filled or canceled.



Ioc

Immediate Or Cancel - The order must be filled immediately in its entirety. If the order cannot be filled completely, the unfilled portion is canceled.



Fok

Fill Or Kill - The order must be filled immediately and completely. If the order cannot be filled entirely, the entire order is canceled.



Gtd(Timestamp)

Good ’Til Date - The order remains active until a specified date and time.

Implementations

Source

impl TimeInForce

pub fn is_immediate(&self) -> bool

Check if the order should be canceled after attempting to match

pub fn has_expiry(&self) -> bool

Check if the order has an expiry time

pub fn expires_at(&self) -> Option<Timestamp>

Get the timestamp when the order expires, if any

pub fn is_expired(&self, timestamp: Timestamp) -> bool

Checks if an order with this time in force has expired