pub struct LevelEntries { /* private fields */ }Expand description
Shared order tracking for a level
Stores the time-priority queue of order entries and the number of active orders.
Note that order_count may differ from queue.len() due to deferred cleanup of stale entries.
Implementations
Sourceimpl LevelEntries
impl LevelEntries
Sourcepub fn order_count(&self) -> u64
pub fn order_count(&self) -> u64
Get the number of orders at this level
Sourcepub fn queue(&self) -> &VecDeque<QueueEntry>
pub fn queue(&self) -> &VecDeque<QueueEntry>
Get the time priority queue of this price level