PriceLevel

Struct PriceLevel 

pub struct PriceLevel { /* private fields */ }
Price level that manages the status of the orders with the same price. It does not store the orders themselves, but only the time priority information of the orders.

Implementations

Source

impl PriceLevel

pub fn new() -> Self

Create a new price level

pub fn visible_quantity(&self) -> Quantity

Get the visible quantity at this price level

pub fn hidden_quantity(&self) -> Quantity

Get the hidden quantity at this price level

pub fn total_quantity(&self) -> Quantity

Get the total quantity at this price level (visible + hidden)

pub fn order_count(&self) -> u64

Get the number of orders at this price level

pub fn queue(&self) -> &VecDeque<QueueEntry>

Get the time priority queue of this price level